EventsManager

Struct EventsManager 

pub struct EventsManager { /* private fields */ }
The events manager providing access to Calendar events via EventKit

Implementations

Source

impl EventsManager

pub fn new() -> Self

Creates a new EventsManager instance

pub fn authorization_status() -> AuthorizationStatus

Gets the current authorization status for calendar events

pub fn request_access(&self) -> Result<bool>

Requests full access to calendar events (blocking)

Returns Ok(true) if access was granted, Ok(false) if denied

pub fn ensure_authorized(&self) -> Result<()>

Ensures we have authorization, requesting if needed

pub fn list_calendars(&self) -> Result<Vec<CalendarInfo>>

Lists all event calendars

pub fn default_calendar(&self) -> Result<CalendarInfo>

Gets the default calendar for new events

pub fn fetch_today_events(&self) -> Result<Vec<EventItem>>

Fetches events for today

pub fn fetch_upcoming_events(&self, days: i64) -> Result<Vec<EventItem>>

Fetches events for the next N days

pub fn fetch_events( &self, start: DateTime<Local>, end: DateTime<Local>, calendar_titles: Option<&[&str]>, ) -> Result<Vec<EventItem>>

Fetches events in a date range

pub fn create_event( &self, title: &str, start: DateTime<Local>, end: DateTime<Local>, notes: Option<&str>, location: Option<&str>, calendar_title: Option<&str>, all_day: bool, ) -> Result<EventItem>

Creates a new event

pub fn update_event( &self, identifier: &str, title: Option<&str>, notes: Option<&str>, location: Option<&str>, start: Option<DateTime<Local>>, end: Option<DateTime<Local>>, ) -> Result<EventItem>

Updates an existing event

pub fn delete_event(&self, identifier: &str, affect_future: bool) -> Result<()>

Deletes an event

pub fn get_event(&self, identifier: &str) -> Result<EventItem>

Gets an event by its identifier

pub fn create_event_calendar(&self, title: &str) -> Result<CalendarInfo>

Creates a new event calendar.

pub fn rename_event_calendar( &self, identifier: &str, new_title: &str, ) -> Result<CalendarInfo>

Renames an event calendar. Rename an event calendar (backward compat wrapper).

pub fn update_event_calendar( &self, identifier: &str, new_title: Option<&str>, color_rgba: Option<(f64, f64, f64, f64)>, ) -> Result<CalendarInfo>

Update an event calendar — name, color, or both.

pub fn delete_event_calendar(&self, identifier: &str) -> Result<()>

Deletes an event calendar.

pub fn get_event_alarms(&self, identifier: &str) -> Result<Vec<AlarmInfo>>

Lists all alarms on an event.

pub fn add_event_alarm(&self, identifier: &str, alarm: &AlarmInfo) -> Result<()>

Adds an alarm to an event.

pub fn get_event_recurrence_rules( &self, identifier: &str, ) -> Result<Vec<RecurrenceRule>>

Gets recurrence rules on an event.

pub fn set_event_recurrence_rule( &self, identifier: &str, rule: &RecurrenceRule, ) -> Result<()>

Sets a recurrence rule on an event (replaces any existing rules).

pub fn remove_event_recurrence_rules(&self, identifier: &str) -> Result<()>

Removes all recurrence rules from an event.

pub fn remove_event_alarm(&self, identifier: &str, index: usize) -> Result<()>

Removes a specific alarm from an event by index.

pub fn set_event_url(&self, identifier: &str, url: Option<&str>) -> Result<()>

Set or clear the URL on an event.